searchData={"items":[{"type":"module","title":"EasyPage.Components.Tabber.Body","doc":"A component which takes :tab slots.\nRenders whichever :tab slot is currently selected, based on title.\n\nTitles must be unique.\n\n> #### Warning {: .warning}\n> \n> Most of Tabber's magic is in the backend, not the components.\n> You are probably better off copying the source code so you can customize it for your app.\n\n```elixir\ndef render(assigns) do\n  ~H\"\"\"\n   \n\n    <:tab title=\"Tab A\">\n       \n    </:tab>\n\n    <:tab title=\"Tab B\">\n       \n    </:tab>\n\n    <:tab title=\"Tab C\">\n       Meow \n    </:tab>\n\n\n   \n  \"\"\"\nend\n```","ref":"EasyPage.Components.Tabber.Body.html"},{"type":"function","title":"EasyPage.Components.Tabber.Body.body/1","doc":"","ref":"EasyPage.Components.Tabber.Body.html#body/1"},{"type":"function","title":"Attributes - EasyPage.Components.Tabber.Body.body/1","doc":"* `tabber` (`:map`) (required)","ref":"EasyPage.Components.Tabber.Body.html#body/1-attributes"},{"type":"function","title":"Slots - EasyPage.Components.Tabber.Body.body/1","doc":"* `tab` - The body of a tab. Accepts attributes:\n\n  * `title` (`:string`) (required)","ref":"EasyPage.Components.Tabber.Body.html#body/1-slots"},{"type":"module","title":"EasyPage.Tabber","doc":"A server side tabination component with lifecycle hooks.\nYou probably do NOT need this, as most use-cases for tabs would be better off with a client-side javascript solution.\n\nOne possible use case for tabber is when you want to lazily load data.\nI.e., call the database on the first time you enter a tab.\n\n# Usage\n\n```elixir\n# Now we create a tab component. \ndefmodule TabA do\n  @behaviour EasyPage.Tabber.Tab\n \n  # All tab callbacks are optional.\n  # They each take a socket, and return a socket\n  @impl true\n  def on_first_enter(socket) do\n    dbg \"some setup stuff\"\n    socket\n  end\n\nend\n\n# And to tie it all together, you must:\n# 1. Initialize it in your liveview,\n# 2. Call the Tabber.Body.body/1 component, and pass each tab into it as a slot.\ndefmodule MyAppWeb.Parent do\n  use MyAppWeb, :live_view\n  alias EasyPage.Components.Tabber\n\n  def mount(_, _, socket) do\n    socket = Tabber.init_tabs(socket, [ \n      {\"Tab A\", TabA}, # <- Each title must be unique\n      {\"Tab B\", TabB}, # But the module need not.\n      {\"Tab C\", TabC} \n  ], default: \"Tab A\")\n    {:ok, socket}\n  end\n\n\n  # Let tabber handle it's own events.\n  @impl true\n  def handle_event(\"tabber_\" <> _ = evt, params, socket) do\n    EasyPage.Tabber.EventHandlers.handle_event(evt, params, socket)\n  end\n\n  def render(assigns) do\n    ~H\"\"\"\n     \n     \n\n     \n      <:tab title=\"Tab A\">\n         Rendering Tab A \n      </:tab>\n\n      <:tab title=\"Tab B\">\n         Rendering Tab B \n      </:tab>\n\n      <:tab title=\"Tab C\">\n         Rendering Tab C \n      </:tab>\n\n     \n    \"\"\"\n  end\nend\n```\n\nTo learn more about Tab modules, look at `EasyPage.Tabber.Tab`","ref":"EasyPage.Tabber.html"},{"type":"function","title":"EasyPage.Tabber.click_tab/2","doc":"Change the current tab, calling all appropriate callback functions as needed.\nTakes either the title, or idx of a tab.\n\nKeep in mind, you probably never need to use this function directly, it is called automatically via \"tabber_\" events.\n\n```elixir\ndef handle_event(\"click\", %{\"tab\" => tab}, socket) do\n  socket = EasyPage.Tabber.click_tab(socket, tab.idx)\n  {:noreply, socket}\nend\n```","ref":"EasyPage.Tabber.html#click_tab/2"},{"type":"function","title":"EasyPage.Tabber.init_tabs/3","doc":"Use this to ensure a specific tab is open upon render. \n\n```elixir\ndef mount(_, _, socket) do\n  socket = EasyPage.Tabber.init_tabs(socket, [\n    {\"My Tab\", module: SomeTab},\n    {\"Another Tab\", module: AnotherTab},\n  ])\n  {:ok, socket}\nend\n```","ref":"EasyPage.Tabber.html#init_tabs/3"},{"type":"function","title":"Options - EasyPage.Tabber.init_tabs/3","doc":"`default (string | nil)`\n\nThis must match one of the tab titles","ref":"EasyPage.Tabber.html#init_tabs/3-options"},{"type":"module","title":"EasyPage.Tabber.NoopTab","doc":"Use this as the tab module when you don't actually need to use any of the lifecycle functions.","ref":"EasyPage.Tabber.NoopTab.html"},{"type":"behaviour","title":"EasyPage.Tabber.Tab","doc":"In order to gain the functionality of tab callbacks, you will need modules that implement the tab lifecycle functions.\nThis may or may not be the Component module.\n\n```elixir\ndefmodule TabA do\n  @behaviour EasyPage.Tabber.Tab\n\n  @impl true\n  def on_init(socket) do\n    IO.puts \"Initialized Tab A\"\n    socket\n  end\n\n  @impl true\n  def on_first_enter(socket) do\n    data = call_database()\n    assign(socket, :data, data)\n  end\nend\n```","ref":"EasyPage.Tabber.Tab.html"},{"type":"callback","title":"EasyPage.Tabber.Tab.on_enter/1","doc":"Called EVERY time a tab is selected","ref":"EasyPage.Tabber.Tab.html#c:on_enter/1"},{"type":"callback","title":"EasyPage.Tabber.Tab.on_exit/1","doc":"Called when the tab is unselected.","ref":"EasyPage.Tabber.Tab.html#c:on_exit/1"},{"type":"callback","title":"EasyPage.Tabber.Tab.on_first_enter/1","doc":"Called ONLY the first time a tab is selected","ref":"EasyPage.Tabber.Tab.html#c:on_first_enter/1"},{"type":"callback","title":"EasyPage.Tabber.Tab.on_init/1","doc":"Called for all tabs during Mount","ref":"EasyPage.Tabber.Tab.html#c:on_init/1"},{"type":"callback","title":"EasyPage.Tabber.Tab.on_not_first_enter/1","doc":"Called every time a tab is selected, except the first time","ref":"EasyPage.Tabber.Tab.html#c:on_not_first_enter/1"},{"type":"task","title":"mix easy_page","doc":"Generates full featured pages, based on the configuration and templates provided.","ref":"Mix.Tasks.EasyPage.html"},{"type":"task","title":"Usage - mix easy_page","doc":"```bash\n> mix easy_page.new index=\"login\" Index=\"Login\"\nScaffolding 'new' with index=\"login\" Index=\"Login\"\nCreated file \"lib/app_web/pages/login/login.ex\"\nCreated file \"lib/app_web/pages/login/mount.ex\"\nCreated file \"lib/app_web/pages/login/handlers.ex\"\nCreated file \"test/app_web/pages/login/login_test.exs\"\n\nYou still need to manually add this page to your router, if not done already.\n```","ref":"Mix.Tasks.EasyPage.html#module-usage"},{"type":"function","title":"Mix.Tasks.EasyPage.run/1","doc":"","ref":"Mix.Tasks.EasyPage.html#run/1"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}